pub unsafe extern "C" fn b2DynamicTree_GetMaxBalance(
tree: *const b2DynamicTree,
) -> c_intExpand description
Get the maximum balance of the tree. The balance is the difference in height of the two children of a node.
pub unsafe extern "C" fn b2DynamicTree_GetMaxBalance(
tree: *const b2DynamicTree,
) -> c_intGet the maximum balance of the tree. The balance is the difference in height of the two children of a node.