b2PrismaticJointDef

Struct b2PrismaticJointDef 

#[repr(C)]
pub struct b2PrismaticJointDef {
Show 18 fields pub bodyIdA: b2BodyId, pub bodyIdB: b2BodyId, pub localAnchorA: b2Vec2, pub localAnchorB: b2Vec2, pub localAxisA: b2Vec2, pub referenceAngle: f32, pub enableSpring: bool, pub hertz: f32, pub dampingRatio: f32, pub enableLimit: bool, pub lowerTranslation: f32, pub upperTranslation: f32, pub enableMotor: bool, pub maxMotorForce: f32, pub motorSpeed: f32, pub collideConnected: bool, pub userData: *mut c_void, pub internalValue: i32,
}
Prismatic joint definition

This requires defining a line of motion using an axis and an anchor point. The definition uses local anchor points and a local axis so that the initial configuration can violate the constraint slightly. The joint translation is zero when the local anchor points coincide in world space. @ingroup prismatic_joint

Fields

bodyIdA: b2BodyId

The first attached body

bodyIdB: b2BodyId

The second attached body

localAnchorA: b2Vec2

The local anchor point relative to bodyA’s origin

localAnchorB: b2Vec2

The local anchor point relative to bodyB’s origin

localAxisA: b2Vec2

The local translation unit axis in bodyA

referenceAngle: f32

The constrained angle between the bodies: bodyB_angle - bodyA_angle

enableSpring: bool

Enable a linear spring along the prismatic joint axis

hertz: f32

The spring stiffness Hertz, cycles per second

dampingRatio: f32

The spring damping ratio, non-dimensional

enableLimit: bool

Enable/disable the joint limit

lowerTranslation: f32

The lower translation limit

upperTranslation: f32

The upper translation limit

enableMotor: bool

Enable/disable the joint motor

maxMotorForce: f32

The maximum motor force, typically in newtons

motorSpeed: f32

The desired motor speed, typically in meters per second

collideConnected: bool

Set this flag to true if the attached bodies should collide

userData: *mut c_void

User data pointer

internalValue: i32

Used internally to detect a valid definition. DO NOT SET.